# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.26.1)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.bloom_filter_json import BloomFilterJSON
from ..models.oauthcommon_user_revocation_list_record import (
    OauthcommonUserRevocationListRecord,
)


class OauthapiRevocationList(Model):
    """Oauthapi revocation list (oauthapi.RevocationList)

    Properties:
        revoked_tokens: (revoked_tokens) REQUIRED BloomFilterJSON

        revoked_users: (revoked_users) REQUIRED List[OauthcommonUserRevocationListRecord]
    """

    # region fields

    revoked_tokens: BloomFilterJSON  # REQUIRED
    revoked_users: List[OauthcommonUserRevocationListRecord]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_revoked_tokens(self, value: BloomFilterJSON) -> OauthapiRevocationList:
        self.revoked_tokens = value
        return self

    def with_revoked_users(
        self, value: List[OauthcommonUserRevocationListRecord]
    ) -> OauthapiRevocationList:
        self.revoked_users = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "revoked_tokens"):
            result["revoked_tokens"] = self.revoked_tokens.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["revoked_tokens"] = BloomFilterJSON()
        if hasattr(self, "revoked_users"):
            result["revoked_users"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.revoked_users
            ]
        elif include_empty:
            result["revoked_users"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        revoked_tokens: BloomFilterJSON,
        revoked_users: List[OauthcommonUserRevocationListRecord],
    ) -> OauthapiRevocationList:
        instance = cls()
        instance.revoked_tokens = revoked_tokens
        instance.revoked_users = revoked_users
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> OauthapiRevocationList:
        instance = cls()
        if not dict_:
            return instance
        if "revoked_tokens" in dict_ and dict_["revoked_tokens"] is not None:
            instance.revoked_tokens = BloomFilterJSON.create_from_dict(
                dict_["revoked_tokens"], include_empty=include_empty
            )
        elif include_empty:
            instance.revoked_tokens = BloomFilterJSON()
        if "revoked_users" in dict_ and dict_["revoked_users"] is not None:
            instance.revoked_users = [
                OauthcommonUserRevocationListRecord.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["revoked_users"]
            ]
        elif include_empty:
            instance.revoked_users = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, OauthapiRevocationList]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[OauthapiRevocationList]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        OauthapiRevocationList,
        List[OauthapiRevocationList],
        Dict[Any, OauthapiRevocationList],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "revoked_tokens": "revoked_tokens",
            "revoked_users": "revoked_users",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "revoked_tokens": True,
            "revoked_users": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsCancelInvitationGroupResponseV2
from ..models import ModelsGetMemberRequestsListResponseV1
from ..models import ResponseErrorResponse

from ..operations.member_request import CancelInvitationGroupMemberV2
from ..operations.member_request import GetGroupInvitationRequestPublicV1
from ..operations.member_request import GetGroupInviteRequestPublicV2
from ..operations.member_request import GetGroupJoinRequestPublicV1
from ..operations.member_request import GetGroupJoinRequestPublicV2
from ..operations.member_request import GetMyGroupJoinRequestV2


@same_doc_as(CancelInvitationGroupMemberV2)
def cancel_invitation_group_member_v2(
    group_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CancelInvitationGroupMemberV2.create(
        group_id=group_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CancelInvitationGroupMemberV2)
async def cancel_invitation_group_member_v2_async(
    group_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CancelInvitationGroupMemberV2.create(
        group_id=group_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGroupInvitationRequestPublicV1)
def get_group_invitation_request_public_v1(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupInvitationRequestPublicV1.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGroupInvitationRequestPublicV1)
async def get_group_invitation_request_public_v1_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupInvitationRequestPublicV1.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGroupInviteRequestPublicV2)
def get_group_invite_request_public_v2(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupInviteRequestPublicV2.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGroupInviteRequestPublicV2)
async def get_group_invite_request_public_v2_async(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupInviteRequestPublicV2.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGroupJoinRequestPublicV1)
def get_group_join_request_public_v1(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupJoinRequestPublicV1.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGroupJoinRequestPublicV1)
async def get_group_join_request_public_v1_async(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupJoinRequestPublicV1.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGroupJoinRequestPublicV2)
def get_group_join_request_public_v2(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupJoinRequestPublicV2.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGroupJoinRequestPublicV2)
async def get_group_join_request_public_v2_async(
    group_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupJoinRequestPublicV2.create(
        group_id=group_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetMyGroupJoinRequestV2)
def get_my_group_join_request_v2(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetMyGroupJoinRequestV2.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetMyGroupJoinRequestV2)
async def get_my_group_join_request_v2_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetMyGroupJoinRequestV2.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.22.1)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class PayPalConfig(Model):
    """A DTO object for updating PayPal config. (PayPalConfig)

    Properties:
        client_id: (clientID) OPTIONAL str

        client_secret: (clientSecret) OPTIONAL str

        return_url: (returnUrl) OPTIONAL str

        web_hook_id: (webHookId) OPTIONAL str
    """

    # region fields

    client_id: str  # OPTIONAL
    client_secret: str  # OPTIONAL
    return_url: str  # OPTIONAL
    web_hook_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_client_id(self, value: str) -> PayPalConfig:
        self.client_id = value
        return self

    def with_client_secret(self, value: str) -> PayPalConfig:
        self.client_secret = value
        return self

    def with_return_url(self, value: str) -> PayPalConfig:
        self.return_url = value
        return self

    def with_web_hook_id(self, value: str) -> PayPalConfig:
        self.web_hook_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id"):
            result["clientID"] = str(self.client_id)
        elif include_empty:
            result["clientID"] = ""
        if hasattr(self, "client_secret"):
            result["clientSecret"] = str(self.client_secret)
        elif include_empty:
            result["clientSecret"] = ""
        if hasattr(self, "return_url"):
            result["returnUrl"] = str(self.return_url)
        elif include_empty:
            result["returnUrl"] = ""
        if hasattr(self, "web_hook_id"):
            result["webHookId"] = str(self.web_hook_id)
        elif include_empty:
            result["webHookId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_id: Optional[str] = None,
        client_secret: Optional[str] = None,
        return_url: Optional[str] = None,
        web_hook_id: Optional[str] = None,
    ) -> PayPalConfig:
        instance = cls()
        if client_id is not None:
            instance.client_id = client_id
        if client_secret is not None:
            instance.client_secret = client_secret
        if return_url is not None:
            instance.return_url = return_url
        if web_hook_id is not None:
            instance.web_hook_id = web_hook_id
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> PayPalConfig:
        instance = cls()
        if not dict_:
            return instance
        if "clientID" in dict_ and dict_["clientID"] is not None:
            instance.client_id = str(dict_["clientID"])
        elif include_empty:
            instance.client_id = ""
        if "clientSecret" in dict_ and dict_["clientSecret"] is not None:
            instance.client_secret = str(dict_["clientSecret"])
        elif include_empty:
            instance.client_secret = ""
        if "returnUrl" in dict_ and dict_["returnUrl"] is not None:
            instance.return_url = str(dict_["returnUrl"])
        elif include_empty:
            instance.return_url = ""
        if "webHookId" in dict_ and dict_["webHookId"] is not None:
            instance.web_hook_id = str(dict_["webHookId"])
        elif include_empty:
            instance.web_hook_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, PayPalConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[PayPalConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[PayPalConfig, List[PayPalConfig], Dict[Any, PayPalConfig]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "clientID": "client_id",
            "clientSecret": "client_secret",
            "returnUrl": "return_url",
            "webHookId": "web_hook_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "clientID": False,
            "clientSecret": False,
            "returnUrl": False,
            "webHookId": False,
        }

    # endregion static methods
